package Sentinel::Test;

use strict;
use vars qw( @ISA %AUTOFIELDS );

use Sentinel::Base;
@ISA = qw( Sentinel::Base );

%AUTOFIELDS = (
	args => undef,
	cdata => undef,
	test => undef,
	message => undef,
	status => undef,
	host => undef
);

sub OBJ_NEW
{
	my $self = shift;

	$self -> args( {} );

	return( $self );
}

sub run_test
{
	my $self = shift;
	my $host = shift;
	my $reason;

	$self -> logmsg( "Test: " . $self -> test() );
	$self -> message( "No Message" );

	# Load the test class
	my $module = "Tests::" . $self -> test();
	$module =~ s/-/_/g;

	my $code;

	# Eval/sig handling so we don't really die
	eval {
		local $SIG{ __DIE__ } = sub { 0 };
		$code = eval( "require $module" );
		$reason = $@;
	};

	if( $code )
	{
		$self -> logmsg( "Module $module loaded" );

		my $test = $module -> new();
		$test -> host( $host );
		$test -> args( $self -> args() );
		$test -> cdata( $self -> cdata() );

		$test -> lib_host( $self -> host() -> lib_host() );
		$test -> lib_port( $self -> host() -> lib_port() );

		# Pass back test status/message
		$self -> status( $test -> execute() );
		$self -> message( $test -> message() );
	}else
	{
		$self -> message( "Could not load: $module ($reason)" );
		$self -> logmsg( "Could not load: $module ($reason)" );
		$self -> status( 1 );
	}

	if( $self -> status() != 0 )
	{
		# Stupid me, must send message here.  The parent doesn't get any of this
		# data
		$self -> logmsg( "Test failed" );
		$self -> host() -> sentinel() ->
			send_notification( $self -> host() -> display_name(),
				"FAIL(" . $self -> test() . ")",
				$self -> message() );
	}

	return( $self -> status() );
}

sub opt
{
	return( shift() -> args() -> { shift() } );
}

1;
