package Tests::disk_usage;

use Tests::Base;
@ISA = qw( Tests::Base );

sub execute
{
	my $self = shift;
	return( $self -> probe_return( undef, 
			$self -> opt( 'dev' ) || '/dev/hda1',
			$self -> opt( 'max' ) || '50' )
	);
}

1;

__END__

=head1 NAME

Tests::disk_usage - tests disk usage, requires probe

=head1 SYNOPSIS

	<disk_usage dev="/dev/dev" max="percent"/>

=head1 DESCRIPTION

Tests disk usage on the host machine being tested.  Tests based on percent of usage
for the disk.  Most useful on machines with mailspools and other variable disk usage
to catch when things are filling up, but also generally useful to watch for unusual
behaviour.

=head2 dev

The device name on the remote machine, such as /dev/hda1.

=head2 max

The maximum percent allowed to be full.  If the percent full is higher the test will fail.
The percentage is expressed in whole percents, like 50 for 50%, not 0.5.

=head1 SEE ALSO

sentinel, probe, librarian, sentinel.conf

=head1 AUTHOR

Steve Slaven - http://hoopajoo.net
