package Tests::loadavg;

use Tests::Base;
@ISA = qw( Tests::Base );

%AUTOFIELDS = (
	retcode => undef 
);

sub execute
{
	my $self = shift;
	my( $one, $five, $fifteen, $running, $total );
	my $foo = $self -> probe();

	if( $foo == 200 )
	{
		# Validate any loadavg data
		( $one, $five, $fifteen, $running, $total ) = split( /,/, $self -> probe_message() );

		$self -> retcode( 0 ); # say OK
		$self -> message( "" ); # Make -w happy

		# Now test each one.  If failure, it will add to message and set retcode,
		# If retcode is one by the end it failed somewhere
		$self -> invalid_value( 'avg1', $one, "Load average too high in last 1 minute" );
		$self -> invalid_value( 'avg5', $five, "Load average too high in last 5 minutes" );
		$self -> invalid_value( 'avg15', $fifteen, "Load average too high in last 15 minutes" );
		$self -> invalid_value( 'running', $running, "Too many running processes" );
		$self -> invalid_value( 'total', $total, "Too many total processes" );

		return( $self -> retcode() );
	}

	$self -> message( $self -> probe_message() );
	return( 1 );
}

sub invalid_value
{
	my $self = shift;
	my $field = shift;
	my $value = shift;
	my $message = shift;

	if( ! defined( $self -> opt( $field ) ) )
	{
		# Was not set, do not check
		return();
	}

	if( $value > $self -> opt( $field ) )
	{
		$self -> message( $self -> message() . 
			$message . 
			": $value max " . 
			$self -> opt( $field ) .
			"\n" );

		# Flag error
		$self -> retcode( 1 );
	}
}

1;

__END__

=head1 NAME

Tests::loadavg - test load average values on remote host, requires probe

=head1 SYNOPSIS

	<loadavg avg1="n" avg5="n" avg15="n" total="n" running="n"/>

=head1 DESCRIPTION

The loadavg plugin tests the loadavg of the remote machine.  Useful to catch runaway processes
that may be sucking the CPU out of the machine, or forking uncontrollably with the "total"
argument.

=head2 avg[1|5|15]

If the load average in the last 5/10/15 minutes is higher than n the test will fail.  The
value tested is the same as the value displayed by top and other process monitor
utilities.

=head2 total

If the total number of processes is greater and n the test will fail, for catching things
forking too much.

=head2 running

Same as other args, but for running processes.  Pretty useless if you ask me, but added
for completeness.

=head1 SEE ALSO

sentinel, probe, librarian, sentinel.conf

=head1 AUTHOR

Steve Slaven - http://hoopajoo.net
